@@ -85,6 +85,11 @@ class backgrounds(TemplateFormat):
         if not force and (width > self.source_width or
                           height > self.source_height):
             return False
+        if ((width == self.source_width and height == self.source_height) and
+                (source.rpartition('.')[2] == target.rpartition('.')[2])):
+            with writeFile(target) as sf:
+                sf.write(readFile(source))
+            return True
         if self.chroot_cmd:
             source = self.trim_chroot_path(source)
             target = self.trim_chroot_path(target)
@@ -168,11 +173,17 @@ class backgrounds(TemplateFormat):
         resolutions = [x.strip() for x in text_list
                        if not x.startswith("#") and x.strip()]
         image_md5 = self.getImageMD5(source, resolutions=resolutions)
+        only_one = len(resolutions) == 1 and self.text.strip()
+        if only_one:
+            image_fn = pathJoin(workdir, prefix)
+            fn_base = image_fn.rpartition(".")[0]
+            if not fn_base:
+                fn_base = image_fn
+            md5_fn = "%s.md5" % fn_base
         if os.path.exists(md5_fn):
             md5sum = readFile(md5_fn).strip()
             if md5sum == image_md5:
                 return ""
-        only_one = len(resolutions) == 1 and self.text.strip()
         if only_one:
             removed_files = [pathJoin(workdir, prefix)]
         else:
@@ -208,10 +219,9 @@ class backgrounds(TemplateFormat):
                 self.parent.printWARNING(
                     _("Skipped creation of the image with %s resolution") % (
                         "%dx%d" % (width, height)))
-        if not only_one:
-            with writeFile(md5_fn) as f:
-                f.write("%s\n" % image_md5)
-            self.changed_files.append(md5_fn)
+        with writeFile(md5_fn) as f:
+            f.write("%s\n" % image_md5)
+        self.changed_files.append(md5_fn)
         for remove_fn in removed_files:
             try:
                 if os.path.lexists(remove_fn):
